/*===============================================================================================================================
                                                                          
        ARTICLE: The Disciplinary Role of Financial Statements: Evidence from Mergers and Acquisitions of Privately Held Targets                      
        AUTHOR: Ciao-Wei Chen                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		CODE3 is used to construct the fourth main dependent variables: 
		acquirer's three-year buy-and-hold stock returns subsequent to an acquisition.

 ===============================================================================================================================*/

libname chen 'C:\Users\ciachen\Desktop\SEC Disclosure and M&A\Data';

*comp_match is the crsp-compustat merged database (quarterly);
*m_crsp is the monthly crsp stock returns file;
*crsp_day_cal_2010 is a list of crsp trading days to get trading day for calendar dates using next day for non-trading days;
*crsp_day_cal_prdt is a list of crsp trading days to get trading day for calendar dates using prior day for non-trading days;

proc freq data = chen.comp_match; tables fyearq; run;

proc sort data = chen.comp_match out = comp_match (where = ((ceqq > .z) and (lpermno > .) and (datadate > .z))) nodupkey;
	by lpermno datadate; 
run;

* set up the begining of quarter date;

data b1;
	set comp_match;
	y = year(datadate); 
	m = month (datadate);
	if m <=2 then do; b_m = 10+m; b_y = y-1; end;
	else if m>2 then do; b_m = m-2; b_y = y; end;
	if m >=10 then do; f_m = m-9; f_y = y+1; end;
	else if m < 10 then do; f_m = m+3; f_y = y; end;
	if f_m = 12 then do; f_m = 1; f_y = f_y+1; end;
	else f_m = f_m + 1;

	b_qtr = mdy(b_m, 1, b_y); format b_qtr date9.;
	f_qtr = mdy(f_m, 1, f_y)-1; format f_qtr date9.;
	drop prccq mkvaltq cshoq;
run;

proc freq data = b1; tables datadate; run;


*get trade date for event date;

proc sql;
	create table b11 as select
	a.caldt, b.*
	from chen.crsp_day_cal_2013_prdt as a, b1 as b
	where a.cal_date = b.datadate;
quit;

*Get the return and price data and assign BVE for each month;

data tsdata;
	set chen.m_crsp (keep = permno exchcd date prc shrout ret);
	shrout = shrout/1000;
run;

data tsdata;
	set tsdata;
	mve = prc*shrout; 
	mve = abs(mve);
	if mve <= . then delete;
run;

proc sql; 
	create table b12 as select 
	a.gvkey, a.lpermno, a.ceqq, a.caldt, a.datadate, a.b_qtr, a.f_qtr, b.exchcd, b.mve, b.ret, 
	(a.ceqq/b.mve) as btm, b.date, b.permno, a.sic
	from tsdata as b left join b11 as a   
	on a.lpermno=b.permno and a.caldt=b.date 
	order by permno, date; 
quit; 


data bhcon (drop = _bv _sic _ddt _bq _fq); 
	set b12; 
	by permno; 
	retain _bv _sic _ddt _bq _fq; 

		if first.permno then do; _bv=.; _sic=.; _ddt=.; _bq=.; _fq=.;end;
		if BTM=. then BTM = _bv; else _bv = BTM;
		if SIC=' ' then SIC=_sic; else _sic=SIC;
		if datadate = . then datadate=_ddt; else _ddt=datadate;
		if b_qtr = . then b_qtr = _bq; else _bq = b_qtr;	
		if f_qtr = . then f_qtr = _fq; else _fq = f_qtr;	
run;

data bhcon; 
	set bhcon; 
	if BTM > .; 
	if mve > .; 
	if sic = ' ' then delete; 
	sic2 = substr(sic,1,2); 
	m=month(date); 
run;

proc sort data=bhcon out=bhcon1 nodupkey; by permno date; run;

data bhcon2;	set bhcon1;
			
				mdiff = m - lag(m);
				if (m > 1) and (m le 12) and (mdiff =1) then m1=1;
				else if m=1 and mdiff=-11 then m1=1; 
								
				if permno = lag(permno) then p1 =1;
				if permno = lag2(permno) then p2 =1;
				if permno = lag3(permno) then p3 =1;
				if permno = lag4(permno) then p4 =1;
				if permno = lag5(permno) then p5 =1;
				if permno = lag6(permno) then p6 =1;
				if permno = lag7(permno) then p7 =1;
				if permno = lag8(permno) then p8 =1;
				if permno = lag9(permno) then p9 =1;
				if permno = lag10(permno) then p10 =1;
				if permno = lag11(permno) then p11 =1;
				if permno = lag12(permno) then p12 =1;

				if lag(m1)=1 then m2=1;
				if lag2(m1)=1 then m3=1;
				if lag3(m1)=1 then m4=1;
				if lag4(m1)=1 then m5=1;
				if lag5(m1)=1 then m6=1;
				if lag6(m1)=1 then m7=1;
				if lag7(m1)=1 then m8=1;
				if lag8(m1)=1 then m9=1;
				if lag9(m1)=1 then m10=1;
				if lag10(m1)=1 then m11=1;
				if lag11(m1)=1 then m12=1;
				
				lret = (1+lag(ret))*p1*m1;
				l2ret = (1+lag2(ret))*p2*m2;
				l3ret = (1+lag3(ret))*p3*m3;
				l4ret = (1+lag4(ret))*p4*m4;
				l5ret = (1+lag5(ret))*p5*m5;
				l6ret = (1+lag6(ret))*p6*m6;
				l7ret = (1+lag7(ret))*p7*m7;
				l8ret = (1+lag8(ret))*p8*m8;
				l9ret = (1+lag9(ret))*p9*m9;
				l10ret = (1+lag10(ret))*p10*m10;
				l11ret = (1+lag11(ret))*p11*m11;
				l12ret = (1+lag12(ret))*p12*m12;

		
				pyret = ((lret*l2ret*l3ret*l4ret*l5ret*l6ret*l7ret*l8ret*l9ret*l10ret*l11ret*l12ret)-1);
				drop p1-p12 m1-m12 mdiff lret l2ret l3ret l4ret l5ret l6ret l7ret l8ret l9ret l10ret
					l11ret l12ret;
run;

*Calculate the 36 month return after the current month;

proc sort data=bhcon2 nodupkey; by permno descending date; run;

data bhcon3;
		set bhcon2;* (where = (permno = 10057));
			
				mdiff = m - lag(m);
				if (m ge 1) and (m < 12) and (mdiff =-1) then m1=1;
				else if m=12 and mdiff=11 then m1=1; 
								
				if permno = lag(permno) then p1 =1;
				if permno = lag2(permno) then p2 =1;
				if permno = lag3(permno) then p3 =1;
				if permno = lag4(permno) then p4 =1;
				if permno = lag5(permno) then p5 =1;
				if permno = lag6(permno) then p6 =1;
				if permno = lag7(permno) then p7 =1;
				if permno = lag8(permno) then p8 =1;
				if permno = lag9(permno) then p9 =1;
				if permno = lag10(permno) then p10 =1;
				if permno = lag11(permno) then p11 =1;
				if permno = lag12(permno) then p12 =1;

				if permno = lag13(permno) then p13 =1;
				if permno = lag14(permno) then p14 =1;
				if permno = lag15(permno) then p15 =1;
				if permno = lag16(permno) then p16 =1;
				if permno = lag17(permno) then p17 =1;
				if permno = lag18(permno) then p18 =1;
				if permno = lag19(permno) then p19 =1;
				if permno = lag20(permno) then p20 =1;
				if permno = lag21(permno) then p21 =1;
				if permno = lag22(permno) then p22 =1;
				if permno = lag23(permno) then p23 =1;
				if permno = lag24(permno) then p24 =1;

				if permno = lag25(permno) then p25 =1;
				if permno = lag26(permno) then p26 =1;
				if permno = lag27(permno) then p27 =1;
				if permno = lag28(permno) then p28 =1;
				if permno = lag29(permno) then p29 =1;
				if permno = lag30(permno) then p30 =1;
				if permno = lag31(permno) then p31 =1;
				if permno = lag32(permno) then p32 =1;
				if permno = lag33(permno) then p33 =1;
				if permno = lag34(permno) then p34 =1;
				if permno = lag35(permno) then p35 =1;
				if permno = lag36(permno) then p36 =1;

				if lag(m1)=1 then m2=1;
				if lag2(m1)=1 then m3=1;
				if lag3(m1)=1 then m4=1;
				if lag4(m1)=1 then m5=1;
				if lag5(m1)=1 then m6=1;
				if lag6(m1)=1 then m7=1;
				if lag7(m1)=1 then m8=1;
				if lag8(m1)=1 then m9=1;
				if lag9(m1)=1 then m10=1;
				if lag10(m1)=1 then m11=1;
				if lag11(m1)=1 then m12=1;

				if lag12(m1)=1 then m13=1;
				if lag13(m1)=1 then m14=1;
				if lag14(m1)=1 then m15=1;
				if lag15(m1)=1 then m16=1;
				if lag16(m1)=1 then m17=1;
				if lag17(m1)=1 then m18=1;
				if lag18(m1)=1 then m19=1;
				if lag19(m1)=1 then m20=1;
				if lag20(m1)=1 then m21=1;
				if lag21(m1)=1 then m22=1;
				if lag22(m1)=1 then m23=1;
				if lag23(m1)=1 then m24=1;
				
				if lag24(m1)=1 then m25=1;
				if lag25(m1)=1 then m26=1;
				if lag26(m1)=1 then m27=1;
				if lag27(m1)=1 then m28=1;
				if lag28(m1)=1 then m29=1;
				if lag29(m1)=1 then m30=1;
				if lag30(m1)=1 then m31=1;
				if lag31(m1)=1 then m32=1;
				if lag32(m1)=1 then m33=1;
				if lag33(m1)=1 then m34=1;
				if lag34(m1)=1 then m35=1;
				if lag35(m1)=1 then m36=1;

				lret = (1+lag(ret))*p1*m1;
				l2ret = (1+lag2(ret))*p2*m2;
				l3ret = (1+lag3(ret))*p3*m3;
				l4ret = (1+lag4(ret))*p4*m4;
				l5ret = (1+lag5(ret))*p5*m5;
				l6ret = (1+lag6(ret))*p6*m6;
				l7ret = (1+lag7(ret))*p7*m7;
				l8ret = (1+lag8(ret))*p8*m8;
				l9ret = (1+lag9(ret))*p9*m9;
				l10ret = (1+lag10(ret))*p10*m10;
				l11ret = (1+lag11(ret))*p11*m11;
				l12ret = (1+lag12(ret))*p12*m12;

				l13ret = (1+lag13(ret))*p13*m13;
				l14ret = (1+lag14(ret))*p14*m14;
				l15ret = (1+lag15(ret))*p15*m15;
				l16ret = (1+lag16(ret))*p16*m16;
				l17ret = (1+lag17(ret))*p17*m17;
				l18ret = (1+lag18(ret))*p18*m18;
				l19ret = (1+lag19(ret))*p19*m19;
				l20ret = (1+lag20(ret))*p20*m20;
				l21ret = (1+lag21(ret))*p21*m21;
				l22ret = (1+lag22(ret))*p22*m22;
				l23ret = (1+lag23(ret))*p23*m23;
				l24ret = (1+lag24(ret))*p24*m24;

				l25ret = (1+lag25(ret))*p25*m25;
				l26ret = (1+lag26(ret))*p26*m26;
				l27ret = (1+lag27(ret))*p27*m27;
				l28ret = (1+lag28(ret))*p28*m28;
				l29ret = (1+lag29(ret))*p29*m29;
				l30ret = (1+lag30(ret))*p30*m30;
				l31ret = (1+lag31(ret))*p31*m31;
				l32ret = (1+lag32(ret))*p32*m32;
				l33ret = (1+lag33(ret))*p33*m33;
				l34ret = (1+lag34(ret))*p34*m34;
				l35ret = (1+lag35(ret))*p35*m35;
				l36ret = (1+lag36(ret))*p36*m36;

		BH1RET = (lret*l2ret*l3ret*l4ret*l5ret*l6ret*l7ret*l8ret*l9ret*l10ret*l11ret*l12ret);
		BH2RET = (BH1RET*l13ret*l14ret*l15ret*l16ret*l17ret*l18ret*l19ret*l20ret*l21ret*l22ret*l23ret*l24ret);
		BH3_post = ((BH2RET*l25ret*l26ret*l27ret*l28ret*l29ret*l30ret*l31ret*l32ret*l33ret*l34ret*l35ret*l36ret)-1);
		BH2_post = BH2RET-1;
		BH1_post = BH1RET-1;
		*BH1_post = (BH1RET*l13ret)-1;
		drop  p1-p36 m1-m36 mdiff bve fyr cusip fye4date lret l2ret l3ret l4ret l5ret l6ret l7ret l8ret l9ret l10ret
					l11ret l12ret l13ret l14ret l15ret l16ret l17ret l18ret l19ret l20ret
					l21ret l22ret l23ret l24ret l25ret l26ret l27ret l28ret l29ret l30ret
					l31ret l32ret l33ret l34ret l35ret l36ret;
run;	

proc means data=bhcon3 n nmiss mean median min max; run;
proc sort data=bhcon3; by permno date; run;

data  bhcon4; set bhcon3;
		if bh3_post > .;
		if pyret > .;
run;

*Set up the size deciles based on only NYSE firms;

proc sort data=bhcon4 (where = (exchcd = 1)) out=nyse; by date mve; run;

proc univariate data=nyse noprint;
	by date;
	var mve;
	output out = size_pct PCTLPTS = 10 20 30 40 50 60 70 80 90 PCTLPRE = mve;
run;

proc sort data=size_pct; by date; run;
proc sort data=bhcon4 out=bhcon5;  by date permno; run;

*label the decile that each firm is in for size;

data bhcon6;
	merge bhcon5 (in=in1) size_pct (in=in2);
		by date;
			sizepct = .;
			if mve le mve10 				then sizepct = 1;
			if (mve > mve10) and (mve le mve20) then sizepct = 6;
			if (mve > mve20) and (mve le mve30) then sizepct = 7;
			if (mve > mve30) and (mve le mve40) then sizepct = 8;
			if (mve > mve40) and (mve le mve50) then sizepct = 9;
			if (mve > mve50) and (mve le mve60) then sizepct = 10;
			if (mve > mve60) and (mve le mve70) then sizepct = 11;
			if (mve > mve70) and (mve le mve80) then sizepct = 12;
			if (mve > mve80) and (mve le mve90) then sizepct = 13;
			if (mve > mve90) 				then sizepct = 14;
run;

proc sort data=bhcon6 (where = (sizepct=1)) out=small; by date permno; run;

proc univariate data=small noprint;
	by date;
	var mve;
	output out = small_pct PCTLPTS = 20 40 60 80 PCTLPRE = smve;
run;
proc sort data=small; by date; run;

data small;
	merge small (in=in1) small_pct (in=in2);
		by date;
			if  mve le smve20 			  then sizepct = 1;
			if (mve > smve20) and (mve le smve40) then sizepct = 2;
			if (mve > smve40) and (mve le smve60) then sizepct = 3;
			if (mve > smve60) and (mve le smve80) then sizepct = 4;
			if (mve > smve80) 			  then sizepct = 5;
run;

*Put togther the lowest decile with the other observations;

proc sort data=bhcon6 (where = (sizepct ne 1)); by permno date; run;
proc sort data=small; by permno date; run;

data bhcon7; merge bhcon6 (in=in1) small (in=in2);	by permno date;
		drop smve20 smve40 smve60 smve80 mve10 mve20 mve30 mve40 mve50 mve60
		     mve70 mve80 mve90;
run;

*Merge together the breakpoints for decile 1 quintiles and other deciles;
data size_pct; merge size_pct (in=in1) small_pct (in=in2);	by date;run;

****************************************************************************
*		Now do an independent sort on BTM                              *
***************************************************************************;
proc univariate data=nyse noprint; by date;	var BTM;
	output out = btm_pct PCTLPTS = 10 20 30 40 50 60 70 80 90 PCTLPRE = btm;
run;

proc sort data=btm_pct; by date; run;
proc sort data=bhcon7; by date permno; run;

*label the decile that each firm is in for size;

data bhcon8; merge bhcon7 (in=in1) btm_pct (in=in2);
		by date;
			btmpct = .;
			if btm le btm10 				then btmpct = 1;
			if (btm > btm10) and (btm le btm20) then btmpct = 2;
			if (btm > btm20) and (btm le btm30) then btmpct = 3;
			if (btm > btm30) and (btm le btm40) then btmpct = 4;
			if (btm > btm40) and (btm le btm50) then btmpct = 5;
			if (btm > btm50) and (btm le btm60) then btmpct = 6;
			if (btm > btm60) and (btm le btm70) then btmpct = 7;
			if (btm > btm70) and (btm le btm80) then btmpct = 8;
			if (btm > btm80) and (btm le btm90) then btmpct = 9;
			if (btm > btm90) 				then btmpct = 10;
	
		drop btm10 btm20 btm30 btm40 btm50 btm60 btm70 btm80 btm90;
run;

proc sort data=bhcon8; by sizepct; run;
proc means data=bhcon8 n mean median std min max q1 q3; by sizepct; var pyret bh1_post mve btm; run;

proc sort data=bhcon8; by btmpct; run;
proc means data=bhcon8 n mean median std min max q1 q3; by btmpct; var pyret bh1_post mve btm; run;

proc freq data=bhcon8; tables sizepct; run;

proc freq data=bhcon8; tables btmpct; run;

*get all firms so can use for acquisition sample;
data chen.allfirm_bhar (keep = permno date btm mve btmpct sizepct pyret bh1_post bh2_post bh3_post); set bhcon8; run;

proc print data=chen.allfirm_bhar (where = (permno in (10056,10107))); run;

/* get the main sample */

data temp; set chen.data; run;

*Get trade date for event date;
proc sql; 
	create table sdcret_tdate as select 
	a.caldt, b.*
	from  chen.crsp_day_cal_2013 as a, temp as b
	where a.cal_date=b.eff;
quit; 

data sdcret; set sdcret_tdate; eff=caldt; drop caldt; run;

proc sql; 
	create table sdcret1 as select 
	a.*, b.mve as b_mve, b.btm as b_btm, b.sic2 as b_sic2, b.datadate, b.gvkey
	from sdcret as a, bhcon8 as b
	where a.permno=b.permno and  datadate < a.ann <= f_qtr; 
quit; 

proc sort data=sdcret1 out=sdcret2 ; by key descending datadate; run;
proc sort data=sdcret2 nodupkey; by key descending datadate; run;

data sdcret2; 
	set sdcret2; 
	cal_qtr = qtr(datadate); 
	dy = year(datadate);
	qtr_dt = mdy(cal_qtr,1,dy); 
	format qtr_dt date9.; 
run;

data s1; 
	set sdcret2; 
	m=month(eff); 
	y=year(eff); 
	if m=12 then do; m=0; y=y+1;end; 
	eff_moend=mdy(m+1,1,y)-1; format eff_moend date9.; 
	*keep eff_date eff_mo_aft;drop m y; 
	if eff>.;
run;

proc sql; 
	create table sdcret2 as select 
	a.caldt as moend_date, b.*
	from chen.crsp_day_cal_2013_prdt as a, s1 as b
	where a.cal_date=b.eff_moend;
quit; 

data sdcret22; 
	set sdcret2; m=month(ann); y=year(ann); 
	if m=12 then do; m=0; y=y+1;end; 
	a_moend=mdy(m+1,1,y)-1; format a_moend date9.; *keep eff_date eff_mo_aft;drop m y; 
run;

proc sql; 
	create table sdcret2 as select 
	a.caldt as amoend_date, b.*
	from chen.crsp_day_cal_2013_prdt as a, sdcret22 as b
	where a.cal_date=b.a_moend;
quit; 

*remove acq firms as control firms;
proc sql; 
	create table remove as select b.permno, b.date
	from sdcret2 as a, chen.allfirm_bhar as b
	where a.permno=b.permno and a.eff-1095 < date <= a.eff+35; 
quit;

proc sort data=remove nodupkey; by permno date;run;
proc sort data=chen.allfirm_bhar; by permno date; run;

data cfirm_mo; 
	merge chen.allfirm_bhar (in=in1) remove (in=in2); 
	by permno date;
	if in1=1 and in2=1 then delete; 
run;

*get acq firm returns;
proc sql; 
	create table acq_firms as select a.*, b.bh1_post, b.bh2_post, b.bh3_post, b.pyret, b.date, b.sizepct, b.btmpct
	from sdcret2 as a, chen.allfirm_bhar as b
	where a.permno=b.permno and a.moend_date = b.date; 
quit; 

*find matches;

proc sql; 
	create table acq_match as select a.*, b.bh1_post as c_bh1, b.bh2_post as c_bh2, b.bh3_post as c_bh3, b.pyret as c_py, b.permno as c_perm
	from acq_firms as a left join cfirm_mo as b
	on a.sizepct=b.sizepct and a.btmpct=b.btmpct and a.date=b.date; 
quit;

*get prior year return based on before announcement;
proc sql; 
	create table acq_match1 as select 
	a.*, b.pyret as a_pyret
	from acq_match as a left join chen.allfirm_bhar as b
	on a.permno=b.permno and a.amoend_date=b.date; 
quit; 

proc sql; 
	create table acq_match2 as select 
	a.*, b.pyret as ac_pyret
	from acq_match1 as a left join cfirm_mo as b
	on a.c_perm=b.permno and a.amoend_date=b.date; 
quit; 

proc means data=acq_match2 n nmiss mean min max; var a_pyret ac_pyret;run;

data acq_match3; 
	set acq_match2; 
	py_diff = abs(pyret-c_py);
	apy_diff = abs(a_pyret-ac_pyret); 
	if bh3_post>.; if c_bh3>.; 
	if apy_diff>.; *if c_py>.; *if pyret>.; 
	a_bhm1=bh1_post-c_bh1; 
	a_bhm2=bh2_post-c_bh2; 
	a_bhm3=bh3_post-c_bh3; 
run;

/* combine acq_match3 and controls and winsorize */

proc sql;
	create table bhar
	as select a.*, b.size, b.lev, b.roa, b.tobin, b.threshold, b.threshold2, b.threshold3, b.trg_size, b.stock, b.cash, b.diffind
	from acq_match3 a, controls b
	where a.key = b.key;
quit;

%winsor(bhar,bhar_win,a_bhm3,1 99);
%winsor(bhar_win,bhar_win,size,1 99);
%winsor(bhar_win,bhar_win,lev,1 99);
%winsor(bhar_win,bhar_win,roa,1 99);
%winsor(bhar_win,bhar_win,tobin,1 99);
%winsor(bhar_win,bhar_win,threshold1,1 99);
%winsor(bhar_win,bhar_win,threshold2,1 99);
%winsor(bhar_win,bhar_win,threshold3,1 99);
%winsor(bhar_win,bhar_win,trg_size,1 99);

data chen.bhar; set bhar_win; run;
